==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/components/fragment-configuration-fields/SelectField.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/components/fragment-configuration-fields/SelectField", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/form', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../plugins/page-design-options/hooks/useStyleBook', '../../../prop-types/index', '../../utils/useId'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.SelectField = void 0;

    var _form = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/form"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _useStyleBook2 = require("../../../plugins/page-design-options/hooks/useStyleBook");

    var _index = require("../../../prop-types/index");

    var _useId = require("../../utils/useId");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var SelectField = function SelectField(_ref) {
      var disabled = _ref.disabled,
          field = _ref.field,
          onValueSelect = _ref.onValueSelect,
          value = _ref.value;
      var inputId = (0, _useId.useId)();

      var _useStyleBook = (0, _useStyleBook2.useStyleBook)(),
          tokenValues = _useStyleBook.tokenValues;

      var validValues = field.typeOptions ? field.typeOptions.validValues : field.validValues;

      var _validValues = _slicedToArray(validValues, 1),
          _validValues$ = _validValues[0],
          firstOption = _validValues$ === void 0 ? {} : _validValues$;

      var _useState = (0, _react.useState)(value || field.defaultValue || firstOption.value),
          _useState2 = _slicedToArray(_useState, 2),
          nextValue = _useState2[0],
          setNextValue = _useState2[1];

      var getFrontendTokenOption = function getFrontendTokenOption(option) {
        var token = tokenValues[option.frontendTokenName];

        if (!token) {
          return option;
        }

        return {
          label: token.label,
          value: option.frontendTokenName
        };
      };

      return _react["default"].createElement(_form["default"].Group, {
        small: true
      }, _react["default"].createElement("label", {
        htmlFor: inputId
      }, field.label), _react["default"].createElement(_form.ClaySelectWithOption, {
        "aria-label": field.label,
        disabled: !!disabled,
        id: inputId,
        onChange: function onChange(event) {
          var nextValue = event.target.options[event.target.selectedIndex].value;
          setNextValue(nextValue);
          onValueSelect(field.name, nextValue);
        },
        options: validValues.map(function (validValue) {
          return validValue.frontendTokenName ? getFrontendTokenOption(validValue) : validValue;
        }),
        value: nextValue
      }));
    };

    exports.SelectField = SelectField;
    //# sourceMappingURL=SelectField.js.map
  }
});
//# sourceMappingURL=SelectField.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/components/fragment-configuration-fields/SelectField.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/components/fragment-configuration-fields/SelectField", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/form', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../plugins/page-design-options/hooks/useStyleBook', '../../../prop-types/index', '../../utils/useId'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.SelectField = void 0;

    var _form = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/form"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _useStyleBook2 = require("../../../plugins/page-design-options/hooks/useStyleBook");

    var _index = require("../../../prop-types/index");

    var _useId = require("../../utils/useId");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var SelectField = function SelectField(_ref) {
      var disabled = _ref.disabled,
          field = _ref.field,
          onValueSelect = _ref.onValueSelect,
          value = _ref.value;
      var inputId = (0, _useId.useId)();

      var _useStyleBook = (0, _useStyleBook2.useStyleBook)(),
          tokenValues = _useStyleBook.tokenValues;

      var validValues = field.typeOptions ? field.typeOptions.validValues : field.validValues;

      var _validValues = _slicedToArray(validValues, 1),
          _validValues$ = _validValues[0],
          firstOption = _validValues$ === void 0 ? {} : _validValues$;

      var _useState = (0, _react.useState)(value || field.defaultValue || firstOption.value),
          _useState2 = _slicedToArray(_useState, 2),
          nextValue = _useState2[0],
          setNextValue = _useState2[1];

      var getFrontendTokenOption = function getFrontendTokenOption(option) {
        var token = tokenValues[option.frontendTokenName];

        if (!token) {
          return option;
        }

        return {
          label: token.label,
          value: option.frontendTokenName
        };
      };

      return (/*#__PURE__*/_react.default.createElement(_form.default.Group, {
          small: true
        }, /*#__PURE__*/_react.default.createElement("label", {
          htmlFor: inputId
        }, field.label), /*#__PURE__*/_react.default.createElement(_form.ClaySelectWithOption, {
          "aria-label": field.label,
          disabled: !!disabled,
          id: inputId,
          onChange: function onChange(event) {
            var nextValue = event.target.options[event.target.selectedIndex].value;
            setNextValue(nextValue);
            onValueSelect(field.name, nextValue);
          },
          options: validValues.map(function (validValue) {
            return validValue.frontendTokenName ? getFrontendTokenOption(validValue) : validValue;
          }),
          value: nextValue
        }))
      );
    };

    exports.SelectField = SelectField;
    //# sourceMappingURL=SelectField.js.map
  }
});
//# sourceMappingURL=SelectField.js.map
